@@ -19,6 +19,7 @@ class User:
         phone: str,
         date_joined: datetime,
         address_line_1: str,
+        address_line_2: str,
         city: str,
         state: str,
         postal_code: str,
@@ -36,6 +37,7 @@ class User:
         self._phone = phone
         self._date_joined = date_joined
         self._address_line_1 = address_line_1
+        self._address_line_2 = address_line_2
         self._city = city
         self._state = state
         self._postal_code = postal_code
@@ -88,9 +90,14 @@ class User:
         """Primary address line of user."""
         return self._address_line_1
 
+    @property
+    def address_line_2(self) -> str:
+        """Secondary address line of user."""
+        return self._address_line_2
+
     @property
     def city(self) -> str:
-        """User's state."""
+        """User's city."""
         return self._city
 
     @property
@@ -142,6 +149,7 @@ class User:
             phone=json['phone'],
             date_joined=helpers.to_datetime(json['date_joined']),
             address_line_1=json['address_line_1'],
+            address_line_2=json.get('address_line_2', ''),
             city=json['city'],
             state=json['state'],
             postal_code=json['postal'],
@@ -337,6 +345,7 @@ class CardStatus(Enum):
     GIFT_UNAVAILABLE = 10
     PROOF_PRINT = 11
     RETURN_TO_SENDER = 12
+    DUPLICATE = 13
 
 class Card:
     """Represents an AMcards card."""
@@ -859,6 +868,56 @@ class CampaignResponse:
             shipping_address=json['shipping_address'],
         )
 
+class CampaignMultiResponse:
+    """Represents AMcards' response for sending a drip campaign to multiple contacts."""
+    def __init__(
+        self,
+        mailing_id: int,
+        contacts_scheduled_count: int,
+        duplicate_contacts_count: int,
+        message: str,
+    ) -> None:
+        self._mailing_id = mailing_id
+        self._contacts_scheduled_count = contacts_scheduled_count
+        self._duplicate_contacts_count = duplicate_contacts_count
+        self._message = message
+
+    __repr__ = helpers.repr
+
+    @property
+    def mailing_id(self) -> int:
+        """Unique id for the :py:class:`mailing <amcards.models.Mailing>` created."""
+        return self._mailing_id
+
+    @property
+    def mailing_link(self) -> str:
+        """This is the link to the mailing list inside of AMcards.com."""
+        return f'https://amcards.com/cards/history/?mailing={self._mailing_id}'
+
+    @property
+    def contacts_scheduled_count(self) -> int:
+        """Number of contacts scheduled for the drip campaign."""
+        return self._contacts_scheduled_count
+
+    @property
+    def duplicate_contacts_count(self) -> int:
+        """Number of contacts that were duplicates and not scheduled."""
+        return self._duplicate_contacts_count
+
+    @property
+    def message(self) -> str:
+        """Represents AMcards' response message for sending a drip campaign to multiple contacts."""
+        return self._message
+
+    @classmethod
+    def _from_json(cls, json: dict):
+        return cls(
+            mailing_id=json['mailing_id'],
+            contacts_scheduled_count=json['contacts_scheduled_count'],
+            duplicate_contacts_count=json['duplicate_contacts_count'],
+            message=json['message'],
+        )
+
 class CardsResponse:
     """Represents AMcards' response for sending multiple cards."""
     def __init__(
